.. SPDX-FileCopyrightText: 2024 Red Hat, Inc
..
.. SPDX-License-Identifier: GPL-2.0-or-later

Command Line Interface Manuals
------------------------------

.. toctree::
   :maxdepth: 2

   cli/fedora-messaging
